package com.caimei365.user.controller;

import com.caimei365.user.idempotent.Idempotent;
import com.caimei365.user.model.ResponseJson;
import com.caimei365.user.service.ShopService;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import org.springframework.http.HttpHeaders;
import org.springframework.web.bind.annotation.*;

/**
 * Description
 *
 * @author : Charles
 * @date : 2021/3/9
 */
@RestController
@RequiredArgsConstructor
@RequestMapping("/user/shop")
public class ShopApi {

    private final ShopService shopService;

    /**
     * PC端供应商注册
     *
     * spi旧接口：supplier/register
     *
     * @param source                注册来源: 0网站 1小程序
     * @param name                  组织名称
     * @param sName                 供应商公司简称(旧：sname)
     * @param bindMobile            企业绑定手机号
     * @param email                 邮箱
     * @param smsCode               手机验证码(旧：mobileCode)
     * @param password              密码
     * @param passWordConfirm       用户确认密码
     * @param linkMan               联系人
     * @param provinceId            省(旧：provinceID)
     * @param cityId                市(旧：cityID)
     * @param townId                所在县区Id(旧：townID)
     * @param address               地址
     * @param socialCreditCode      统一社会信用代码
     * @param businessLicenseImage  营业执照
     * @param firstShopType         医疗=1和非医疗=2
     * @param secondShopType        医疗的二级分类 一类器械=1、二类器械 =2、三类器械=3、其他=4 /// 1和非医疗没有二级分类
     * @param mainPro               主打项目(旧:mainpro)
     * @param isAgreed              是否同意勾选同意协议，1是，其他否
     * @param serverWebExchange     ServerWebExchange(新参数)
     */
    @Idempotent(prefix="idempotent_club", keys={"#baseUser"}, expire=5)
    @PostMapping("/pc/register")
    public ResponseJson pcRegister(Integer source,
                                   String name,
                                   String sName,
                                   String bindMobile,
                                   String email,
                                   String smsCode,
                                   String password,
                                   String passWordConfirm,
                                   String linkMan,
                                   Integer provinceId,
                                   Integer cityId,
                                   Integer townId,
                                   String address,
                                   String socialCreditCode,
                                   String businessLicenseImage,
                                   String firstShopType,
                                   String secondShopType,
                                   String mainPro,
                                   Integer isAgreed,
                                   @RequestHeader HttpHeaders headers) {
        return shopService.register(source, name, sName, bindMobile, email, smsCode, password, passWordConfirm, linkMan, provinceId, cityId, townId, address, socialCreditCode, businessLicenseImage, firstShopType, secondShopType, mainPro, isAgreed, headers);
    }

    /**
     * 小程序端分步供应商注册
     *
     * @param source               注册来源: 0网站 1小程序
     * @param name                 组织名称
     * @param sName                供应商公司简称(旧：sname)
     * @param bindMobile           企业绑定手机号
     * @param email                邮箱
     * @param smsCode              手机验证码(旧：mobileCode)
     * @param password             密码
     * @param passWordConfirm      用户确认密码
     * @param linkMan              联系人
     * @param provinceId           省(旧：provinceID)
     * @param cityId               市(旧：cityID)
     * @param townId               所在县区Id(旧：townID)
     * @param address              地址
     * @param socialCreditCode     统一社会信用代码
     * @param businessLicenseImage 营业执照
     * @param firstShopType        医疗=1和非医疗=2
     * @param secondShopType       医疗的二级分类 一类器械=1、二类器械 =2、三类器械=3、其他=4 /// 1和非医疗没有二级分类
     * @param mainPro              主打项目(旧:mainpro)
     * @param isAgreed             是否同意勾选同意协议，1是，其他否
     * @param serverWebExchange    ServerWebExchange(新参数)
     * @param whichStep            注册步数
     * @return
     */
    @ApiOperation("小程序端分步供应商注册")
    @ApiImplicitParam(name = "name", value = "供应商名称", required = true, dataType = "String")
    @PostMapping("/applets/register")
    public ResponseJson appletsRegister(Integer source,
                                        String name,
                                        String sName,
                                        String bindMobile,
                                        String email,
                                        String smsCode,
                                        String password,
                                        String passWordConfirm,
                                        String linkMan,
                                        Integer provinceId,
                                        Integer cityId,
                                        Integer townId,
                                        String address,
                                        String socialCreditCode,
                                        String businessLicenseImage,
                                        String firstShopType,
                                        String secondShopType,
                                        String mainPro,
                                        Integer isAgreed,
                                        Integer whichStep,
                                        @RequestHeader HttpHeaders headers) {
        return shopService.appletsRegister(source, name, sName, bindMobile, email, smsCode, password, passWordConfirm, linkMan, provinceId, cityId, townId, address, socialCreditCode, businessLicenseImage, firstShopType, secondShopType, mainPro, isAgreed, whichStep, headers);
    }

}
