package com.caimei365.user.service;

import com.caimei365.user.model.ResponseJson;
import com.caimei365.user.model.vo.UserLoginVo;
import org.springframework.http.HttpHeaders;


/**
 * Description
 *
 * @author : Charles
 * @date : 2021/3/8
 */
public interface LoginService {

    /**
     * 登录(用户名，密码)
     *
     * @param mobileOrEmail 手机号或邮箱
     * @param password      密码
     * @return BaseUser
     */
    ResponseJson<UserLoginVo> passwordLogin(String mobileOrEmail, String password);

    /**
     * 微信授权登录（小程序）
     *
     * @param code          微信授权code
     * @param encryptedData 微信加密数据
     * @param iv            加密算法的初始向量
     * @return BaseUser
     */
    ResponseJson<UserLoginVo> appletsAuthorization(String code, String encryptedData, String iv, HttpHeaders headers);

    /**
     * 微信公众号授权链接(www)
     *
     * @param redirectUri 用于微信授权的中间页面
     * @param mode        授权方式：1静默授权，其他手动同意授权
     */
    ResponseJson<String> getAuthorizationLink(String redirectUri, Integer mode);

    /**
     * 微信公众号授权登录(www)
     *
     * spi旧接口：user/authorizationLogin
     *
     * @param code  微信code
     * @param state 安全认证
     * @param mode  1:静默授权,2:用户手动授权
     */
    ResponseJson<UserLoginVo> websiteAuthorization(String code, String state, Integer mode, HttpHeaders headers);

    /**
     * 微信扫码登录
     *
     * @param code      微信code
     * @param state     安全认证
     */
    void qrCodeAuthorization(String code, String state);

    /**
     * netty长连接验证登录
     * @param state     安全认证
     * @return
     */
    ResponseJson nettyAuthorization(String state);
}
